@@ -1,13 +1,17 @@
 /*
- * $Id: ngrep.h,v 1.14 2000/06/21 18:42:53 jpr5 Exp $
+ * $Id: ngrep.h,v 1.5 2001/02/27 06:09:25 jpr5 Exp $
  *
- * Copyright (c) 2000  Jordan Ritter <jpr5@darkridge.com>
+ * Copyright (c) 2001  Jordan Ritter <jpr5@darkridge.com>
  *
  * Please refer to the COPYRIGHT file for more information. 
  *
  */
 
+#define VERSION "1.39"
+
+
 #define ETHHDR_SIZE 14 
+#define TOKENRING_SIZE 22
 #define PPPHDR_SIZE 4 
 #define SLIPHDR_SIZE 16
 #define RAWHDR_SIZE 0
@@ -36,6 +40,10 @@ int blank_match_func(char *, int);
 int strishex(char *);
 
 void print_time_absolute(struct pcap_pkthdr *);
+void print_time_diff_init(struct pcap_pkthdr *);
 void print_time_diff(struct pcap_pkthdr *);
 
-void dump_delay(struct pcap_pkthdr *);
+void dump_delay_proc_init(struct pcap_pkthdr *);
+void dump_delay_proc(struct pcap_pkthdr *);
+
+void update_windowsize(int);
